==> ui-framework-4.6.2-sources.jar: io/intino/alexandria/ui/displays/items/Grouping2Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class Grouping2Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName2 firstName2;
	public Gro_42_7_02043339169 gro_42_7_02043339169;
	public Grouping2Mold.Gro_42_7_02043339169. Gender2 gender2;
	public Grouping2Mold.Gro_42_7_02043339169. Age2 age2;

    public Grouping2Mold(UiFrameworkBox box) {
        super(box);
        id("a1951333656");
    }

    @Override
	public void init() {
		super.init();
		if (firstName2 == null) firstName2 = register(new FirstName2(box()).<FirstName2>id("a_296158274").owner(Grouping2Mold.this));
		if (gro_42_7_02043339169 == null) gro_42_7_02043339169 = register(new Gro_42_7_02043339169(box()).<Gro_42_7_02043339169>id("a32190625").owner(Grouping2Mold.this));
		if (gro_42_7_02043339169 != null) gender2 = gro_42_7_02043339169.gender2;
		if (gro_42_7_02043339169 != null) age2 = gro_42_7_02043339169.age2;
	}

	public class FirstName2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName2(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class Gro_42_7_02043339169 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public Grouping2Mold.Gro_42_7_02043339169. Gender2 gender2;
		public Grouping2Mold.Gro_42_7_02043339169. Age2 age2;

		public Gro_42_7_02043339169(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender2 == null) gender2 = register(new Gender2(box()).<Gender2>id("a617609892").owner(Grouping2Mold.this));
			if (age2 == null) age2 = register(new Age2(box()).<Age2>id("a1049977568").owner(Grouping2Mold.this));
		}

		public class Gender2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender2(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age2(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> ui-framework-4.14.8-sources.jar: io/intino/alexandria/ui/displays/items/Grouping2Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class Grouping2Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName2 firstName2;
	public _42_7_02043339169 _42_7_02043339169;
	public Grouping2Mold._42_7_02043339169. Gender2 gender2;
	public Grouping2Mold._42_7_02043339169. Age2 age2;

    public Grouping2Mold(UiFrameworkBox box) {
        super(box);
        id("a1951333656");
    }

    @Override
	public void init() {
		super.init();
		if (firstName2 == null) firstName2 = register(new FirstName2(box()).<FirstName2>id("a_296158274").owner(Grouping2Mold.this));
		if (_42_7_02043339169 == null) _42_7_02043339169 = register(new _42_7_02043339169(box()).<_42_7_02043339169>id("a2097508567").owner(Grouping2Mold.this));
		if (_42_7_02043339169 != null) gender2 = _42_7_02043339169.gender2;
		if (_42_7_02043339169 != null) age2 = _42_7_02043339169.age2;
	}

	public class FirstName2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName2(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _42_7_02043339169 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public Grouping2Mold._42_7_02043339169. Gender2 gender2;
		public Grouping2Mold._42_7_02043339169. Age2 age2;

		public _42_7_02043339169(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender2 == null) gender2 = register(new Gender2(box()).<Gender2>id("a617609892").owner(Grouping2Mold.this));
			if (age2 == null) age2 = register(new Age2(box()).<Age2>id("a1049977568").owner(Grouping2Mold.this));
		}

		public class Gender2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender2(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age2 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age2(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}
